# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class PgoTaskReviewsToCreateStatus(Enum):
    """An enumeration representing different categories.

    :cvar APPROVED: "approved"
    :vartype APPROVED: str
    :cvar DECLINED: "declined"
    :vartype DECLINED: str
    """

    APPROVED = "approved"
    DECLINED = "declined"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, PgoTaskReviewsToCreateStatus._member_map_.values())
        )


@JsonMap({})
class PgoTaskReviewsToCreate(BaseModel):
    """PgoTaskReviewsToCreate

    :param status: Review status.
    :type status: PgoTaskReviewsToCreateStatus
    :param reason: Additional comments with the reivew., defaults to None
    :type reason: str, optional
    :param ids: ids
    :type ids: List[str]
    """

    def __init__(
        self, status: PgoTaskReviewsToCreateStatus, ids: List[str], reason: str = None
    ):
        self.status = self._enum_matching(
            status, PgoTaskReviewsToCreateStatus.list(), "status"
        )
        if reason is not None:
            self.reason = reason
        self.ids = ids
