# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HrisTeamInformation(BaseModel):
    """HrisTeamInformation

    :param team_id: team_id
    :type team_id: float
    :param legal_entity_id: legal_entity_id
    :type legal_entity_id: float
    """

    def __init__(self, team_id: float, legal_entity_id: float):
        self.team_id = team_id
        self.legal_entity_id = legal_entity_id
