# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class UploadEmployeeComplianceDocumentFileContainer(BaseModel):
    """UploadEmployeeComplianceDocumentFileContainer

    :param file: The employee compliance document to upload.
    :type file: str
    """

    def __init__(self, file: str):
        self.file = file
