# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee import Employee
from .page_info_without_cursor_new import PageInfoWithoutCursorNew


@JsonMap({})
class PeopleContainer(BaseModel):
    """PeopleContainer

    :param data: data
    :type data: List[Employee]
    :param page: page, defaults to None
    :type page: PageInfoWithoutCursorNew, optional
    """

    def __init__(self, data: List[Employee], page: PageInfoWithoutCursorNew = None):
        self.data = self._define_list(data, Employee)
        if page is not None:
            self.page = self._define_object(page, PageInfoWithoutCursorNew)
