# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class MilestoneToCreateFormWithFile(BaseModel):
    """MilestoneToCreateFormWithFile

    :param amount: Amount to be paid for the milestone.
    :type amount: str
    :param title: Title of milestone.
    :type title: str
    :param description: Description of milestone.
    :type description: str
    :param file: Upload the file you want to attach to this entry., defaults to None
    :type file: str, optional
    """

    def __init__(self, amount: str, title: str, description: str, file: str = None):
        self.amount = amount
        self.title = title
        self.description = description
        if file is not None:
            self.file = file
