# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_adjustment_created import InvoiceAdjustmentCreated


@JsonMap({})
class InvoiceAdjustmentCreatedContainer(BaseModel):
    """InvoiceAdjustmentCreatedContainer

    :param data: Details of invoice adjustment created.
    :type data: InvoiceAdjustmentCreated
    """

    def __init__(self, data: InvoiceAdjustmentCreated):
        self.data = self._define_object(data, InvoiceAdjustmentCreated)
