# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_adjustment_to_create import InvoiceAdjustmentToCreate


@JsonMap({})
class InvoiceAdjustmentToCreateContainer(BaseModel):
    """InvoiceAdjustmentToCreateContainer

    :param data: Details of invoice adjustment to create.
    :type data: InvoiceAdjustmentToCreate
    """

    def __init__(self, data: InvoiceAdjustmentToCreate):
        self.data = self._define_object(data, InvoiceAdjustmentToCreate)
