# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class InvitationsOfBasicContract(BaseModel):
    """InvitationsOfBasicContract

    :param client_email: User's email address., defaults to None
    :type client_email: str, optional
    :param worker_email: User's email address., defaults to None
    :type worker_email: str, optional
    """

    def __init__(self, client_email: str = None, worker_email: str = None):
        if client_email is not None:
            self.client_email = client_email
        if worker_email is not None:
            self.worker_email = worker_email
