# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GenericResultDeletedData(BaseModel):
    """GenericResultDeletedData

    :param deleted: Confirms the deletion.
    :type deleted: bool
    """

    def __init__(self, deleted: bool):
        self.deleted = deleted


@JsonMap({})
class GenericResultDeleted(BaseModel):
    """GenericResultDeleted

    :param data: data
    :type data: GenericResultDeletedData
    """

    def __init__(self, data: GenericResultDeletedData):
        self.data = self._define_object(data, GenericResultDeletedData)
