# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import Union
from typing import List
from .base import OneOfBaseModel
from .legal_entity_type import LegalEntityType


class GetInvoiceListEntitiesGuard(OneOfBaseModel):
    class_list = {
        "List[LegalEntityType]": List[LegalEntityType],
        "LegalEntityTypeEnum": str,
    }


GetInvoiceListEntities = Union[List[LegalEntityType], str]
