# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class InvoiceDownloadObject(BaseModel):
    """InvoiceDownloadObject

    :param url: URL to requested invoice to download.
    :type url: str
    """

    def __init__(self, url: str):
        self.url = url
