# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PeoplePayment(BaseModel):
    """PeoplePayment

    :param rate: The payment rate, defaults to None
    :type rate: float, optional
    :param scale: The payment scale (e.g., hourly, weekly, monthly, etc.), defaults to None
    :type scale: str, optional
    :param currency: The currency code (ISO 4217) for the payment, defaults to None
    :type currency: str, optional
    :param contract_name: The name of the contract associated with the payment, defaults to None
    :type contract_name: str, optional
    """

    def __init__(
        self,
        rate: float = None,
        scale: str = None,
        currency: str = None,
        contract_name: str = None,
    ):
        if rate is not None:
            self.rate = rate
        if scale is not None:
            self.scale = scale
        if currency is not None:
            self.currency = currency
        if contract_name is not None:
            self.contract_name = contract_name
