# This file was generated by liblab | https://liblab.com/

from enum import Enum


class ValidationTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar MIN_LENGTH: "MIN_LENGTH"
    :vartype MIN_LENGTH: str
    :cvar MAX_LENGTH: "MAX_LENGTH"
    :vartype MAX_LENGTH: str
    :cvar REGEX: "REGEX"
    :vartype REGEX: str
    """

    MIN_LENGTH = "MIN_LENGTH"
    MAX_LENGTH = "MAX_LENGTH"
    REGEX = "REGEX"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ValidationTypeEnum._member_map_.values()))
