# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .final_payment_calculated import FinalPaymentCalculated


@JsonMap({})
class FinalPaymentCalculatedContainer(BaseModel):
    """FinalPaymentCalculatedContainer

    :param data: data
    :type data: FinalPaymentCalculated
    """

    def __init__(self, data: FinalPaymentCalculated):
        self.data = self._define_object(data, FinalPaymentCalculated)
