# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class Currency(BaseModel):
    """Currency

    :param code: code
    :type code: str
    :param name: name
    :type name: str
    """

    def __init__(self, code: str, name: str):
        self.code = self._pattern_matching(code, "^[A-Z]{3}$", "code")
        self.name = name
