# This file was generated by liblab | https://liblab.com/

from typing import Union
from .base import OneOfBaseModel


class TimesheetIdItemsGuard(OneOfBaseModel):
    class_list = {"float": float, "str": str}


TimesheetIdItems = Union[float, str]
