# This file was generated by liblab | https://liblab.com/

from enum import Enum


class ContractWhoReportsEnum(Enum):
    """An enumeration representing different categories.

    :cvar BOTH: "both"
    :vartype BOTH: str
    :cvar CLIENT: "client"
    :vartype CLIENT: str
    :cvar CONTRACTOR: "contractor"
    :vartype CONTRACTOR: str
    """

    BOTH = "both"
    CLIENT = "client"
    CONTRACTOR = "contractor"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ContractWhoReportsEnum._member_map_.values())
        )
