# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class EmployeeTimeoffsEntitlementsItem(BaseModel):
    """EmployeeTimeoffsEntitlementsItem

    :param year: year
    :type year: float
    :param tracking_period: tracking_period
    :type tracking_period: str
    :param vacation_allowed: vacation_allowed
    :type vacation_allowed: str
    :param vacation_rollover: vacation_rollover
    :type vacation_rollover: str
    :param vacation_expired: vacation_expired
    :type vacation_expired: str
    :param vacation_payout: vacation_payout
    :type vacation_payout: str
    :param vacation_requested: vacation_requested
    :type vacation_requested: str
    :param vacation_approved: vacation_approved
    :type vacation_approved: str
    :param vacation_used: vacation_used
    :type vacation_used: str
    :param vacation_total: vacation_total
    :type vacation_total: str
    :param sick_leave_requested: sick_leave_requested
    :type sick_leave_requested: str
    :param sick_leave_approved: sick_leave_approved
    :type sick_leave_approved: str
    :param sick_leave_used: sick_leave_used
    :type sick_leave_used: str
    :param sick_leave_total: sick_leave_total
    :type sick_leave_total: str
    :param sick_leave_allowed: sick_leave_allowed
    :type sick_leave_allowed: str
    :param other_leave_requested: other_leave_requested
    :type other_leave_requested: str
    :param other_leave_approved: other_leave_approved
    :type other_leave_approved: str
    :param other_leave_used: other_leave_used
    :type other_leave_used: str
    :param other_leave_total: other_leave_total
    :type other_leave_total: str
    """

    def __init__(
        self,
        year: float,
        tracking_period: str,
        vacation_allowed: str,
        vacation_rollover: str,
        vacation_expired: str,
        vacation_payout: str,
        vacation_requested: str,
        vacation_approved: str,
        vacation_used: str,
        vacation_total: str,
        sick_leave_requested: str,
        sick_leave_approved: str,
        sick_leave_used: str,
        sick_leave_total: str,
        sick_leave_allowed: str,
        other_leave_requested: str,
        other_leave_approved: str,
        other_leave_used: str,
        other_leave_total: str,
    ):
        self.year = year
        self.tracking_period = tracking_period
        self.vacation_allowed = vacation_allowed
        self.vacation_rollover = vacation_rollover
        self.vacation_expired = vacation_expired
        self.vacation_payout = vacation_payout
        self.vacation_requested = vacation_requested
        self.vacation_approved = vacation_approved
        self.vacation_used = vacation_used
        self.vacation_total = vacation_total
        self.sick_leave_requested = sick_leave_requested
        self.sick_leave_approved = sick_leave_approved
        self.sick_leave_used = sick_leave_used
        self.sick_leave_total = sick_leave_total
        self.sick_leave_allowed = sick_leave_allowed
        self.other_leave_requested = other_leave_requested
        self.other_leave_approved = other_leave_approved
        self.other_leave_used = other_leave_used
        self.other_leave_total = other_leave_total
