# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class ContractTerminationResult(BaseModel):
    """ContractTerminationResult

    :param id_: Deel Contract ID., defaults to None
    :type id_: str, optional
    :param completion_date: Short date in format ISO-8601 (YYYY-MM-DD). For example 2022-12-31., defaults to None
    :type completion_date: str, optional
    """

    def __init__(self, id_: str = None, completion_date: str = None):
        if id_ is not None:
            self.id_ = id_
        if completion_date is not None:
            self.completion_date = self._pattern_matching(
                completion_date, "^\d{4}-\d{2}-\d{2}$", "completion_date"
            )
