# This file was generated by liblab | https://liblab.com/

from enum import Enum


class WorkStatementCycleScaleEnum(Enum):
    """An enumeration representing different categories.

    :cvar WEEKLY: "weekly"
    :vartype WEEKLY: str
    :cvar MONTHLY: "monthly"
    :vartype MONTHLY: str
    :cvar BIWEEKLY: "biweekly"
    :vartype BIWEEKLY: str
    :cvar SEMIMONTHLY: "semimonthly"
    :vartype SEMIMONTHLY: str
    :cvar CALENDAR_MONTH: "calendar-month"
    :vartype CALENDAR_MONTH: str
    """

    WEEKLY = "weekly"
    MONTHLY = "monthly"
    BIWEEKLY = "biweekly"
    SEMIMONTHLY = "semimonthly"
    CALENDAR_MONTH = "calendar-month"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, WorkStatementCycleScaleEnum._member_map_.values())
        )
