# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContractInvitationToCreate(BaseModel):
    """ContractInvitationToCreate

    :param email: Worker's email address.
    :type email: str
    :param message: Message for the worker.
    :type message: str
    """

    def __init__(self, email: str, message: str):
        self.email = email
        self.message = message
