# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee_timeoffs_item import EmployeeTimeoffsItem


@JsonMap({})
class EmployeeTimeoffsContainer(BaseModel):
    """EmployeeTimeoffsContainer

    :param data: List of employee time offs., defaults to None
    :type data: List[EmployeeTimeoffsItem], optional
    """

    def __init__(self, data: List[EmployeeTimeoffsItem] = None):
        if data is not None:
            self.data = self._define_list(data, EmployeeTimeoffsItem)
