# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContractExternalIdToPatch(BaseModel):
    """ContractExternalIdToPatch

    :param external_id: A unique identifier for the object provided by an external system.
    :type external_id: str
    """

    def __init__(self, external_id: str):
        self.external_id = external_id
