# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GpContractSalaryScaleEnum(Enum):
    """An enumeration representing different categories.

    :cvar YEAR: "YEAR"
    :vartype YEAR: str
    :cvar MONTH: "MONTH"
    :vartype MONTH: str
    :cvar HOUR: "HOUR"
    :vartype HOUR: str
    """

    YEAR = "YEAR"
    MONTH = "MONTH"
    HOUR = "HOUR"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, GpContractSalaryScaleEnum._member_map_.values())
        )
