# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .webhook_event_type_response import WebhookEventTypeResponse


@JsonMap({})
class WebhookEventTypeListResponse(BaseModel):
    """WebhookEventTypeListResponse

    :param data: data, defaults to None
    :type data: List[WebhookEventTypeResponse], optional
    """

    def __init__(self, data: List[WebhookEventTypeResponse] = None):
        if data is not None:
            self.data = self._define_list(data, WebhookEventTypeResponse)
