# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HrisDirectEmployeeDetails(BaseModel):
    """HrisDirectEmployeeDetails

    :param first_name: first_name
    :type first_name: str
    :param last_name: last_name
    :type last_name: str
    :param email: email
    :type email: str
    :param work_email: work_email
    :type work_email: str
    :param nationality: nationality
    :type nationality: str
    :param country: country
    :type country: str
    :param state: state, defaults to None
    :type state: str, optional
    """

    def __init__(
        self,
        first_name: str,
        last_name: str,
        email: str,
        work_email: str,
        nationality: str,
        country: str,
        state: str = None,
    ):
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.work_email = work_email
        self.nationality = nationality
        self.country = country
        if state is not None:
            self.state = state
