# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .payment_method_enum import PaymentMethodEnum


@JsonMap({"type_": "type"})
class PaymentMethod(BaseModel):
    """PaymentMethod

    :param type_: All the supported payment types, defaults to None
    :type type_: PaymentMethodEnum, optional
    """

    def __init__(self, type_: PaymentMethodEnum = None):
        if type_ is not None:
            self.type_ = self._enum_matching(type_, PaymentMethodEnum.list(), "type_")
