# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PublicToken(BaseModel):
    """PublicToken

    :param token: Public token.
    :type token: str
    """

    def __init__(self, token: str):
        self.token = token
