# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "pic_url": "picUrl"})
class PaymentWorker(BaseModel):
    """PaymentWorker

    :param id_: Worker's unique id., defaults to None
    :type id_: float, optional
    :param name: Worker's full name.
    :type name: str
    :param pic_url: URL to worker's Deel avatar.
    :type pic_url: str
    :param contract_id: The worker's Deel contract Id., defaults to None
    :type contract_id: str, optional
    """

    def __init__(
        self, name: str, pic_url: str, id_: float = None, contract_id: str = None
    ):
        if id_ is not None:
            self.id_ = id_
        self.name = name
        self.pic_url = pic_url
        if contract_id is not None:
            self.contract_id = contract_id
