# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"type_": "type"})
class Email(BaseModel):
    """Email

    :param type_: The type of email., defaults to None
    :type type_: str, optional
    :param value: The email address., defaults to None
    :type value: str, optional
    """

    def __init__(self, type_: str = None, value: str = None):
        if type_ is not None:
            self.type_ = type_
        if value is not None:
            self.value = value
