# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class SignaturesOfContract(BaseModel):
    """SignaturesOfContract

    :param client_signature: normally name of client is used as signature
    :type client_signature: str
    :param client_signed_at: Long date-time format following ISO-8601
    :type client_signed_at: str
    :param worker_signature: Signatures of client representative.
    :type worker_signature: str
    :param worker_signed_at: Long date-time format following ISO-8601
    :type worker_signed_at: str
    :param signed_at: Long date-time format following ISO-8601
    :type signed_at: str
    """

    def __init__(
        self,
        client_signature: str,
        client_signed_at: str,
        worker_signature: str,
        worker_signed_at: str,
        signed_at: str,
    ):
        self.client_signature = client_signature
        self.client_signed_at = client_signed_at
        self.worker_signature = worker_signature
        self.worker_signed_at = worker_signed_at
        self.signed_at = signed_at
