# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class Departments(BaseModel):
    """Departments

    :param id_: id_
    :type id_: float
    :param name: name
    :type name: str
    :param parent: parent, defaults to None
    :type parent: str, optional
    """

    def __init__(self, id_: float, name: str, parent: str = None):
        self.id_ = id_
        self.name = name
        if parent is not None:
            self.parent = parent
