# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class PensionEorContractToCreate(BaseModel):
    """Some countries required a pension benefit.

    :param id_: Pension provider id. You can see available pension providers in the country guide endpoint., defaults to None
    :type id_: str, optional
    :param contribution: Enter the value of pension contribution. You should send this value only if the contribution object is available in the country guide endpoint and the value should be there between minimum and maximum values indicated., defaults to None
    :type contribution: str, optional
    """

    def __init__(self, id_: str = None, contribution: str = None):
        if id_ is not None:
            self.id_ = id_
        if contribution is not None:
            self.contribution = contribution
