# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .identifier_value import IdentifierValue, IdentifierValueGuard


@JsonMap({"id_": "id"})
class SeniorityRequired(BaseModel):
    """Seniority describes level of expertise at a job e.g. junior

    :param id_: id_
    :type id_: IdentifierValue
    :param name: Name of seniority level e.g. Mid (Individual Contributor Level 2)
    :type name: str
    :param level: Level of seniority level e.g. 2
    :type level: float
    """

    def __init__(self, id_: IdentifierValue, name: str, level: float):
        self.id_ = IdentifierValueGuard.return_one_of(id_)
        self.name = name
        self.level = level
