# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .candidate_to_patch import CandidateToPatch


@JsonMap({})
class CandidateToPatchContainer(BaseModel):
    """CandidateToPatchContainer

    :param data: Details of candidate to update
    :type data: CandidateToPatch
    """

    def __init__(self, data: CandidateToPatch):
        self.data = self._define_object(data, CandidateToPatch)
