# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class OffCyclePaymentToCreate(BaseModel):
    """Details of invoice adjustment to create.

    :param date_submitted: Short date in format ISO-8601 (YYYY-MM-DD). For example: 2022-12-31.
    :type date_submitted: str
    :param amount: Amount to be paid. Must be a positive number.
    :type amount: float
    :param description: Description of off-cycle payment., defaults to None
    :type description: str, optional
    """

    def __init__(self, date_submitted: str, amount: float, description: str = None):
        self.date_submitted = date_submitted
        self.amount = amount
        if description is not None:
            self.description = description
