# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .basic_organization import BasicOrganization


@JsonMap({})
class OrganizationListContainer(BaseModel):
    """OrganizationListContainer

    :param data: data
    :type data: List[BasicOrganization]
    """

    def __init__(self, data: List[BasicOrganization]):
        self.data = self._define_list(data, BasicOrganization)
