# This file was generated by liblab | https://liblab.com/

from enum import Enum


class PeopleSortByEnum(Enum):
    """An enumeration representing different categories.

    :cvar ID: "id"
    :vartype ID: str
    :cvar FIRST_NAME: "first_name"
    :vartype FIRST_NAME: str
    :cvar LAST_NAME: "last_name"
    :vartype LAST_NAME: str
    :cvar FULL_NAME: "full_name"
    :vartype FULL_NAME: str
    :cvar EMAIL: "email"
    :vartype EMAIL: str
    :cvar COUNTRY: "country"
    :vartype COUNTRY: str
    :cvar BIRTH_DATE: "birth_date"
    :vartype BIRTH_DATE: str
    :cvar HIRING_TYPE: "hiring_type"
    :vartype HIRING_TYPE: str
    :cvar START_DATE: "start_date"
    :vartype START_DATE: str
    :cvar TEAM: "team"
    :vartype TEAM: str
    :cvar JOB_TITLE: "job_title"
    :vartype JOB_TITLE: str
    :cvar HIRING_STATUS: "hiring_status"
    :vartype HIRING_STATUS: str
    :cvar COMPLETION_DATE: "completion_date"
    :vartype COMPLETION_DATE: str
    :cvar DIRECT_MANAGER: "direct_manager"
    :vartype DIRECT_MANAGER: str
    :cvar DIRECT_REPORTS_COUNT: "direct_reports_count"
    :vartype DIRECT_REPORTS_COUNT: str
    """

    ID = "id"
    FIRST_NAME = "first_name"
    LAST_NAME = "last_name"
    FULL_NAME = "full_name"
    EMAIL = "email"
    COUNTRY = "country"
    BIRTH_DATE = "birth_date"
    HIRING_TYPE = "hiring_type"
    START_DATE = "start_date"
    TEAM = "team"
    JOB_TITLE = "job_title"
    HIRING_STATUS = "hiring_status"
    COMPLETION_DATE = "completion_date"
    DIRECT_MANAGER = "direct_manager"
    DIRECT_REPORTS_COUNT = "direct_reports_count"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PeopleSortByEnum._member_map_.values()))
