# This file was generated by liblab | https://liblab.com/

from enum import Enum


class MaritalStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar SINGLE: "Single"
    :vartype SINGLE: str
    :cvar MARRIED: "Married"
    :vartype MARRIED: str
    :cvar WIDOWED: "Widowed"
    :vartype WIDOWED: str
    :cvar DIVORCED: "Divorced"
    :vartype DIVORCED: str
    :cvar SEPARATED: "Separated"
    :vartype SEPARATED: str
    :cvar REGISTERED_PARTNERSHIP: "Registered Partnership"
    :vartype REGISTERED_PARTNERSHIP: str
    :cvar COMMON_LAW: "Common Law"
    :vartype COMMON_LAW: str
    """

    SINGLE = "Single"
    MARRIED = "Married"
    WIDOWED = "Widowed"
    DIVORCED = "Divorced"
    SEPARATED = "Separated"
    REGISTERED_PARTNERSHIP = "Registered Partnership"
    COMMON_LAW = "Common Law"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, MaritalStatusEnum._member_map_.values()))
