# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"type_": "type", "id_": "id"})
class EmployeeTaxDocumentsList(BaseModel):
    """EmployeeTaxDocumentsList

    :param year: year, defaults to None
    :type year: float, optional
    :param type_: type_, defaults to None
    :type type_: str, optional
    :param country: country, defaults to None
    :type country: str, optional
    :param id_: id_, defaults to None
    :type id_: str, optional
    :param url: url, defaults to None
    :type url: str, optional
    """

    def __init__(
        self,
        year: float = None,
        type_: str = None,
        country: str = None,
        id_: str = None,
        url: str = None,
    ):
        if year is not None:
            self.year = year
        if type_ is not None:
            self.type_ = type_
        if country is not None:
            self.country = country
        if id_ is not None:
            self.id_ = id_
        if url is not None:
            self.url = url
