# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_entitlement_list_item import EorEntitlementListItem


@JsonMap({})
class EorEntitlements(BaseModel):
    """Time-off Entitlements for EOR contracts.

    :param entitlements: List of entitlements.
    :type entitlements: List[EorEntitlementListItem]
    """

    def __init__(self, entitlements: List[EorEntitlementListItem]):
        self.entitlements = self._define_list(entitlements, EorEntitlementListItem)
