# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CreatePublicToken(BaseModel):
    """CreatePublicToken

    :param scope: Access scopes., defaults to None
    :type scope: List[str], optional
    """

    def __init__(self, scope: List[str] = None):
        if scope is not None:
            self.scope = scope
