# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .premium_to_add import PremiumToAdd


@JsonMap({})
class PremiumToAddContainer(BaseModel):
    """PremiumToAddContainer

    :param data: data
    :type data: PremiumToAdd
    """

    def __init__(self, data: PremiumToAdd):
        self.data = self._define_object(data, PremiumToAdd)
