# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class StateOfCountry(BaseModel):
    """It may be called states, provinces, prefectures or regions, or none at all

    :param code: Territory code.
    :type code: str
    :param name: Territory name.
    :type name: str
    """

    def __init__(self, code: str, name: str):
        self.code = code
        self.name = name
