# This file was generated by liblab | https://liblab.com/

from typing import Union
from .base import OneOfBaseModel


class IdentifierValueGuard(OneOfBaseModel):
    class_list = {"str": str, "int": int}


IdentifierValue = Union[str, int]
