# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PageInfo(BaseModel):
    """PageInfo

    :param cursor: cursor
    :type cursor: str
    :param total_rows: total_rows
    :type total_rows: float
    """

    def __init__(self, cursor: str, total_rows: float):
        self.cursor = cursor
        self.total_rows = total_rows
