# This file was generated by liblab | https://liblab.com/

from enum import Enum


class WorkStatementPaymentDueTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar REGULAR: "REGULAR"
    :vartype REGULAR: str
    :cvar WITHIN_MONTH: "WITHIN_MONTH"
    :vartype WITHIN_MONTH: str
    """

    REGULAR = "REGULAR"
    WITHIN_MONTH = "WITHIN_MONTH"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, WorkStatementPaymentDueTypeEnum._member_map_.values()
            )
        )
