# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .output_to_create_file_ref import OutputToCreateFileRef


@JsonMap({})
class OutputToCreateFileRefContainer(BaseModel):
    """OutputToCreateFileRefContainer

    :param data: data
    :type data: OutputToCreateFileRef
    """

    def __init__(self, data: OutputToCreateFileRef):
        self.data = self._define_object(data, OutputToCreateFileRef)
