# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .payment import Payment


@JsonMap({})
class PaymentObject(BaseModel):
    """PaymentObject

    :param rows: rows, defaults to None
    :type rows: List[Payment], optional
    :param total: total, defaults to None
    :type total: float, optional
    """

    def __init__(self, rows: List[Payment] = None, total: float = None):
        if rows is not None:
            self.rows = self._define_list(rows, Payment)
        if total is not None:
            self.total = total
