# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_timeoffs_base_item import EorTimeoffsBaseItem


@JsonMap({})
class EorTimeoffsContainer(BaseModel):
    """EorTimeoffsContainer

    :param data: List of time offs.
    :type data: List[EorTimeoffsBaseItem]
    """

    def __init__(self, data: List[EorTimeoffsBaseItem]):
        self.data = self._define_list(data, EorTimeoffsBaseItem)
