# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "type_": "type"})
class WorkerDocument(BaseModel):
    """WorkerDocument

    :param id_: Document unique ID., defaults to None
    :type id_: str, optional
    :param type_: Document type., defaults to None
    :type type_: str, optional
    :param contractor_signed_at: Date the contractor singed the document., defaults to None
    :type contractor_signed_at: str, optional
    :param client_signed_at: Date the client singed the document., defaults to None
    :type client_signed_at: str, optional
    :param label: Document name., defaults to None
    :type label: str, optional
    """

    def __init__(
        self,
        id_: str = None,
        type_: str = None,
        contractor_signed_at: str = None,
        client_signed_at: str = None,
        label: str = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if type_ is not None:
            self.type_ = type_
        if contractor_signed_at is not None:
            self.contractor_signed_at = contractor_signed_at
        if client_signed_at is not None:
            self.client_signed_at = client_signed_at
        if label is not None:
            self.label = label
