# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BankAccountStatus(Enum):
    """An enumeration representing different categories.

    :cvar NEW: "new"
    :vartype NEW: str
    :cvar PENDING: "pending"
    :vartype PENDING: str
    :cvar APPROVED: "approved"
    :vartype APPROVED: str
    :cvar FAILED: "failed"
    :vartype FAILED: str
    """

    NEW = "new"
    PENDING = "pending"
    APPROVED = "approved"
    FAILED = "failed"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, BankAccountStatus._member_map_.values()))
