# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HrisJobInformationTitleId(BaseModel):
    """HrisJobInformationTitleId

    :param seniority_id: seniority_id
    :type seniority_id: float
    :param job_title_id: job_title_id
    :type job_title_id: float
    """

    def __init__(self, seniority_id: float, job_title_id: float):
        self.seniority_id = seniority_id
        self.job_title_id = job_title_id
