# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "from_": "from"})
class Payslips(BaseModel):
    """Payslips

    :param id_: Unique identifier for the payslip.
    :type id_: str
    :param from_: Start date of the payslip.
    :type from_: str
    :param to: End date of the payslip.
    :type to: str
    :param status: Status of the payslip.
    :type status: str
    """

    def __init__(self, id_: str, from_: str, to: str, status: str):
        self.id_ = id_
        self.from_ = from_
        self.to = to
        self.status = status
