# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class FileObject(BaseModel):
    """This is the file you will upload in a multi-part form.

    :param file: Upload the file you want to attach to this entry., defaults to None
    :type file: str, optional
    """

    def __init__(self, file: str = None):
        if file is not None:
            self.file = file
