# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HrisCompensation(BaseModel):
    """HrisCompensation

    :param gross_annual_salary: gross_annual_salary
    :type gross_annual_salary: float
    :param currency: currency
    :type currency: str
    """

    def __init__(self, gross_annual_salary: float, currency: str):
        self.gross_annual_salary = gross_annual_salary
        self.currency = currency
