# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class BasicTeam(BaseModel):
    """BasicTeam

    :param id_: Unique identifier of this resource.
    :type id_: str
    :param name: name
    :type name: str
    """

    def __init__(self, id_: str, name: str):
        self.id_ = id_
        self.name = name
