# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "from_": "from"})
class EmployeePayslipsList(BaseModel):
    """EmployeePayslipsList

    :param id_: id_
    :type id_: str
    :param from_: from_
    :type from_: str
    :param to: to
    :type to: str
    :param filename: filename
    :type filename: str
    :param status: status
    :type status: str
    :param rejected_at: rejected_at
    :type rejected_at: str
    :param reject_reason: reject_reason
    :type reject_reason: str
    :param uploaded_at: uploaded_at
    :type uploaded_at: str
    :param published_at: published_at
    :type published_at: str
    :param schedule_publishing_date: schedule_publishing_date
    :type schedule_publishing_date: str
    :param created_at: created_at
    :type created_at: str
    :param updated_at: updated_at
    :type updated_at: str
    :param url: url
    :type url: str
    """

    def __init__(
        self,
        id_: str,
        from_: str,
        to: str,
        filename: str,
        status: str,
        rejected_at: str,
        reject_reason: str,
        uploaded_at: str,
        published_at: str,
        schedule_publishing_date: str,
        created_at: str,
        updated_at: str,
        url: str,
    ):
        self.id_ = id_
        self.from_ = from_
        self.to = to
        self.filename = filename
        self.status = status
        self.rejected_at = rejected_at
        self.reject_reason = reject_reason
        self.uploaded_at = uploaded_at
        self.published_at = published_at
        self.schedule_publishing_date = schedule_publishing_date
        self.created_at = created_at
        self.updated_at = updated_at
        self.url = url
