# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_timeoffs_employee_item import EorTimeoffsEmployeeItem


@JsonMap({})
class EorClientTimeoffs(BaseModel):
    """EorClientTimeoffs

    :param employees: List of employee time offs.
    :type employees: List[EorTimeoffsEmployeeItem]
    :param total_requests: total_requests
    :type total_requests: float
    """

    def __init__(self, employees: List[EorTimeoffsEmployeeItem], total_requests: float):
        self.employees = self._define_list(employees, EorTimeoffsEmployeeItem)
        self.total_requests = total_requests
