# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee_contract_signature_to_create import EmployeeContractSignatureToCreate


@JsonMap({})
class EmployeeContractSignatureToCreateContainer(BaseModel):
    """EmployeeContractSignatureToCreateContainer

    :param data: data
    :type data: EmployeeContractSignatureToCreate
    """

    def __init__(self, data: EmployeeContractSignatureToCreate):
        self.data = self._define_object(data, EmployeeContractSignatureToCreate)
