# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .identifier_value import IdentifierValue, IdentifierValueGuard


@JsonMap({"id_": "id"})
class ContractTemplate(BaseModel):
    """Contract template details.

    :param id_: id_, defaults to None
    :type id_: IdentifierValue, optional
    :param title: Title of a contract template, defaults to None
    :type title: str, optional
    """

    def __init__(self, id_: IdentifierValue = None, title: str = None):
        if id_ is not None:
            self.id_ = IdentifierValueGuard.return_one_of(id_)
        if title is not None:
            self.title = title
