# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .update_worker_working_location import UpdateWorkerWorkingLocation


@JsonMap({})
class UpdateWorkerWorkingLocationContainer(BaseModel):
    """UpdateWorkerWorkingLocationContainer

    :param data: data
    :type data: UpdateWorkerWorkingLocation
    """

    def __init__(self, data: UpdateWorkerWorkingLocation):
        self.data = self._define_object(data, UpdateWorkerWorkingLocation)
