# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_entitlements import EorEntitlements


@JsonMap({})
class EorEntitlementsContainer(BaseModel):
    """EorEntitlementsContainer

    :param data: Time-off Entitlements for EOR contracts.
    :type data: EorEntitlements
    """

    def __init__(self, data: EorEntitlements):
        self.data = self._define_object(data, EorEntitlements)
