# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GpContractSalaryStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar ACTIVE: "ACTIVE"
    :vartype ACTIVE: str
    :cvar UPCOMING: "UPCOMING"
    :vartype UPCOMING: str
    :cvar OUTDATED: "OUTDATED"
    :vartype OUTDATED: str
    """

    ACTIVE = "ACTIVE"
    UPCOMING = "UPCOMING"
    OUTDATED = "OUTDATED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, GpContractSalaryStatusEnum._member_map_.values())
        )
