# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContractCustomField(BaseModel):
    """Customized attributes on contracts (Employee ID, Project code, etc).

    :param name: Custom field property name., defaults to None
    :type name: str, optional
    :param value: Custom field property value., defaults to None
    :type value: str, optional
    """

    def __init__(self, name: str = None, value: str = None):
        if name is not None:
            self.name = name
        if value is not None:
            self.value = value
