# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class InvoiceAdjustmentReviewToCreateStatus(Enum):
    """An enumeration representing different categories.

    :cvar APPROVED: "approved"
    :vartype APPROVED: str
    :cvar DECLINED: "declined"
    :vartype DECLINED: str
    """

    APPROVED = "approved"
    DECLINED = "declined"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                InvoiceAdjustmentReviewToCreateStatus._member_map_.values(),
            )
        )


@JsonMap({})
class InvoiceAdjustmentReviewToCreate(BaseModel):
    """InvoiceAdjustmentReviewToCreate

    :param status: status
    :type status: InvoiceAdjustmentReviewToCreateStatus
    :param reason: reason
    :type reason: str
    """

    def __init__(self, status: InvoiceAdjustmentReviewToCreateStatus, reason: str):
        self.status = self._enum_matching(
            status, InvoiceAdjustmentReviewToCreateStatus.list(), "status"
        )
        self.reason = reason
