# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class MetaDataOfContractToCreate(BaseModel):
    """Additional custom info about a contract

    :param documents_required: Require the contractor to upload necessary compliance documents as per their country’s labor laws.
    :type documents_required: bool
    :param is_main_income: is_main_income, defaults to None
    :type is_main_income: bool, optional
    """

    def __init__(self, documents_required: bool, is_main_income: bool = None):
        self.documents_required = documents_required
        if is_main_income is not None:
            self.is_main_income = is_main_income
