# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .basic_timesheet import BasicTimesheet
from .page_info_without_cursor import PageInfoWithoutCursor


@JsonMap({})
class TimesheetListContainer(BaseModel):
    """TimesheetListContainer

    :param data: data
    :type data: List[BasicTimesheet]
    :param page: page
    :type page: PageInfoWithoutCursor
    """

    def __init__(self, data: List[BasicTimesheet], page: PageInfoWithoutCursor):
        self.data = self._define_list(data, BasicTimesheet)
        self.page = self._define_object(page, PageInfoWithoutCursor)
