# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_employee_cost_calculation_request_body import (
    EorEmployeeCostCalculationRequestBody,
)


@JsonMap({})
class EorEmployeeCostCalculationRequestBodyContainer(BaseModel):
    """EorEmployeeCostCalculationRequestBodyContainer

    :param data: data
    :type data: EorEmployeeCostCalculationRequestBody
    """

    def __init__(self, data: EorEmployeeCostCalculationRequestBody):
        self.data = self._define_object(data, EorEmployeeCostCalculationRequestBody)
