# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class BankAccountToAdd(BaseModel):
    """BankAccountToAdd

    :param key: The key of the bank account properties.
    :type key: str
    :param value: The value for that key property.
    :type value: str
    """

    def __init__(self, key: str, value: str):
        self.key = key
        self.value = value
