# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .timesheet_shared_properties import TimesheetSharedProperties


@JsonMap({})
class TimesheetToCreateContainer(BaseModel):
    """TimesheetToCreateContainer

    :param data: Details of the timesheet to create. Both a client or a contractor may create a timesheet.
    :type data: TimesheetSharedProperties
    """

    def __init__(self, data: TimesheetSharedProperties):
        self.data = self._define_object(data, TimesheetSharedProperties)
