# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .worker_document_download_link import WorkerDocumentDownloadLink


@JsonMap({})
class DownloadWorkerDocumentsByIdContainer(BaseModel):
    """DownloadWorkerDocumentsByIdContainer

    :param data: data
    :type data: WorkerDocumentDownloadLink
    """

    def __init__(self, data: WorkerDocumentDownloadLink):
        self.data = self._define_object(data, WorkerDocumentDownloadLink)
