# This file was generated by liblab | https://liblab.com/

from enum import Enum


class EorHolidaysRolloverType(Enum):
    """An enumeration representing different categories.

    :cvar EXPIRATION: "EXPIRATION"
    :vartype EXPIRATION: str
    :cvar PAY_OUT: "PAY_OUT"
    :vartype PAY_OUT: str
    :cvar UNLIMITED_ROLLOVER: "UNLIMITED_ROLLOVER"
    :vartype UNLIMITED_ROLLOVER: str
    :cvar LIMITED_ROLLOVER: "LIMITED_ROLLOVER"
    :vartype LIMITED_ROLLOVER: str
    :cvar UNSET: "UNSET"
    :vartype UNSET: str
    """

    EXPIRATION = "EXPIRATION"
    PAY_OUT = "PAY_OUT"
    UNLIMITED_ROLLOVER = "UNLIMITED_ROLLOVER"
    LIMITED_ROLLOVER = "LIMITED_ROLLOVER"
    UNSET = "UNSET"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, EorHolidaysRolloverType._member_map_.values())
        )
