# This file was generated by liblab | https://liblab.com/

from enum import Enum


class InvoiceStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar PENDING: "pending"
    :vartype PENDING: str
    :cvar PAID: "paid"
    :vartype PAID: str
    :cvar PROCESSING: "processing"
    :vartype PROCESSING: str
    :cvar CANCELED: "canceled"
    :vartype CANCELED: str
    :cvar SKIPPED: "skipped"
    :vartype SKIPPED: str
    :cvar FAILED: "failed"
    :vartype FAILED: str
    :cvar REFUNDED: "refunded"
    :vartype REFUNDED: str
    """

    PENDING = "pending"
    PAID = "paid"
    PROCESSING = "processing"
    CANCELED = "canceled"
    SKIPPED = "skipped"
    FAILED = "failed"
    REFUNDED = "refunded"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, InvoiceStatusEnum._member_map_.values()))
