# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class EmployeeAgreementDownloadObject(BaseModel):
    """EmployeeAgreementDownloadObject

    :param url: URL to requested employee agreement to download., defaults to None
    :type url: str, optional
    :param expires_at: Expiration date time of download URL., defaults to None
    :type expires_at: str, optional
    """

    def __init__(self, url: str = None, expires_at: str = None):
        if url is not None:
            self.url = url
        if expires_at is not None:
            self.expires_at = expires_at
