# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .legal_entity_type import LegalEntityType


@JsonMap({"type_": "type"})
class WorkerLegalEntity(BaseModel):
    """WorkerLegalEntity

    :param type_: type_
    :type type_: LegalEntityType
    :param personal_name: personal_name
    :type personal_name: str
    :param registration_number: registration_number
    :type registration_number: str
    """

    def __init__(
        self, type_: LegalEntityType, personal_name: str, registration_number: str
    ):
        self.type_ = self._enum_matching(type_, LegalEntityType.list(), "type_")
        self.personal_name = personal_name
        self.registration_number = registration_number
