# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .adjustment_to_update import AdjustmentToUpdate


@JsonMap({})
class AdjustmentToUpdateContainer(BaseModel):
    """AdjustmentToUpdateContainer

    :param data: Details of adjustment to update
    :type data: AdjustmentToUpdate
    """

    def __init__(self, data: AdjustmentToUpdate):
        self.data = self._define_object(data, AdjustmentToUpdate)
