# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .pgo_task_reviews_to_create import PgoTaskReviewsToCreate


@JsonMap({})
class RequestBodyToCreatePgoTaskReviewsReviewsContainer(BaseModel):
    """RequestBodyToCreatePgoTaskReviewsReviewsContainer

    :param data: data
    :type data: PgoTaskReviewsToCreate
    """

    def __init__(self, data: PgoTaskReviewsToCreate):
        self.data = self._define_object(data, PgoTaskReviewsToCreate)
