# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class UpdateWorkerWorkingLocation(BaseModel):
    """UpdateWorkerWorkingLocation

    :param working_location_id: Unique identifier of this resource.
    :type working_location_id: str
    """

    def __init__(self, working_location_id: str):
        self.working_location_id = working_location_id
