# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class UploadEmployeeComplianceDocumentContainerData(BaseModel):
    """UploadEmployeeComplianceDocumentContainerData

    :param success: A flag denoting if the file upload was successful., defaults to None
    :type success: bool, optional
    """

    def __init__(self, success: bool = None):
        if success is not None:
            self.success = success


@JsonMap({})
class UploadEmployeeComplianceDocumentContainer(BaseModel):
    """UploadEmployeeComplianceDocumentContainer

    :param data: data
    :type data: UploadEmployeeComplianceDocumentContainerData
    """

    def __init__(self, data: UploadEmployeeComplianceDocumentContainerData):
        self.data = self._define_object(
            data, UploadEmployeeComplianceDocumentContainerData
        )
