# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class AdminUserCreateRequest(BaseModel):
    """AdminUserCreateRequest

    :param first_name: User's first name
    :type first_name: str
    :param last_name: User's last name
    :type last_name: str
    :param email: User's email
    :type email: str
    """

    def __init__(self, first_name: str, last_name: str, email: str):
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
