# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class AdditionalEorInfoContainer(BaseModel):
    """AdditionalEorInfoContainer

    :param data: Fields for country validation mandatory found at `/eor/validations/{country_code}`.
    :type data: any
    """

    def __init__(self, data: any):
        self.data = data
