# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_to_create_ongoing_time_based import ContractToCreateOngoingTimeBased


@JsonMap({})
class ContractToCreateContainerOngoingTimeBased(BaseModel):
    """ContractToCreateContainerOngoingTimeBased

    :param data: data
    :type data: ContractToCreateOngoingTimeBased
    """

    def __init__(self, data: ContractToCreateOngoingTimeBased):
        self.data = self._define_object(data, ContractToCreateOngoingTimeBased)
