# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_to_create import ContractToCreate, ContractToCreateGuard
from .contract_to_create_pay_as_you_go_time_based import (
    ContractToCreatePayAsYouGoTimeBased,
)
from .contract_to_create_payg_tasks import ContractToCreatePaygTasks
from .contract_to_create_payg_milestones import ContractToCreatePaygMilestones
from .contract_to_create_ongoing_time_based import ContractToCreateOngoingTimeBased


@JsonMap({})
class ContractToCreateContainer(BaseModel):
    """ContractToCreateContainer

    :param data: data
    :type data: ContractToCreate
    """

    def __init__(self, data: ContractToCreate):
        self.data = ContractToCreateGuard.return_one_of(data)
