# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TimeoffReview(BaseModel):
    """TimeoffReview

    :param is_approved: Approve or decline employee's time off request.
    :type is_approved: bool
    :param denial_reason: Denial reason for the time off requested., defaults to None
    :type denial_reason: str, optional
    """

    def __init__(self, is_approved: bool, denial_reason: str = None):
        self.is_approved = is_approved
        if denial_reason is not None:
            self.denial_reason = denial_reason
