# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class AdminUser(BaseModel):
    """AdminUser

    :param id_: Unique identifier of this resource.
    :type id_: str
    :param first_name: User's first name
    :type first_name: str
    :param last_name: User's last name
    :type last_name: str
    :param email: User's email
    :type email: str
    """

    def __init__(self, id_: str, first_name: str, last_name: str, email: str):
        self.id_ = id_
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
