# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_download_object import InvoiceDownloadObject


@JsonMap({})
class InvoiceDownloadLinkContainer(BaseModel):
    """InvoiceDownloadLinkContainer

    :param data: data
    :type data: InvoiceDownloadObject
    """

    def __init__(self, data: InvoiceDownloadObject):
        self.data = self._define_object(data, InvoiceDownloadObject)
