# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_to_create_payg_milestones import ContractToCreatePaygMilestones


@JsonMap({})
class ContractToCreateContainerPaygMilestones(BaseModel):
    """ContractToCreateContainerPaygMilestones

    :param data: data
    :type data: ContractToCreatePaygMilestones
    """

    def __init__(self, data: ContractToCreatePaygMilestones):
        self.data = self._define_object(data, ContractToCreatePaygMilestones)
