# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .off_cycle_payment_to_create import OffCyclePaymentToCreate


@JsonMap({})
class OffCyclePaymentToCreateContainer(BaseModel):
    """OffCyclePaymentToCreateContainer

    :param data: Details of invoice adjustment to create.
    :type data: OffCyclePaymentToCreate
    """

    def __init__(self, data: OffCyclePaymentToCreate):
        self.data = self._define_object(data, OffCyclePaymentToCreate)
