# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class MonthlyPayment(BaseModel):
    """Monthly payment details for the user

    :param count: The number of monthly payments, defaults to None
    :type count: int, optional
    """

    def __init__(self, count: int = None):
        if count is not None:
            self.count = count
