# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class GpClientLegalEntity(BaseModel):
    """GpClientLegalEntity

    :param id_: Unique identifier of this resource.
    :type id_: str
    """

    def __init__(self, id_: str):
        self.id_ = id_


@JsonMap({"id_": "id"})
class GpClientTeam(BaseModel):
    """GpClientTeam

    :param id_: Unique identifier of this resource.
    :type id_: str
    """

    def __init__(self, id_: str):
        self.id_ = id_


@JsonMap({})
class GpClient(BaseModel):
    """GpClient

    :param legal_entity: legal_entity
    :type legal_entity: GpClientLegalEntity
    :param team: team
    :type team: GpClientTeam
    """

    def __init__(self, legal_entity: GpClientLegalEntity, team: GpClientTeam):
        self.legal_entity = self._define_object(legal_entity, GpClientLegalEntity)
        self.team = self._define_object(team, GpClientTeam)
