# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GpEmployeePtoUpdateData(BaseModel):
    """GpEmployeePtoUpdateData

    :param accrual_start_date: Short date in format ISO-8601 (YYYY-MM-DD). For example: 2022-12-31.
    :type accrual_start_date: str
    :param yearly_allowance: Enter the number of holidays.
    :type yearly_allowance: str
    """

    def __init__(self, accrual_start_date: str, yearly_allowance: str):
        self.accrual_start_date = accrual_start_date
        self.yearly_allowance = yearly_allowance
