# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TimesheetToUpdate(BaseModel):
    """Details of the timesheet to update. Both a client or a contractor may update a timesheet.

    :param description: description
    :type description: str
    :param quantity: quantity
    :type quantity: float
    """

    def __init__(self, description: str, quantity: float):
        self.description = description
        self.quantity = quantity
