# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BenefitContributionTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar PERCENTAGE: "PERCENTAGE"
    :vartype PERCENTAGE: str
    :cvar FIXED_AMOUNT: "FIXED_AMOUNT"
    :vartype FIXED_AMOUNT: str
    :cvar MATCH: "MATCH"
    :vartype MATCH: str
    """

    PERCENTAGE = "PERCENTAGE"
    FIXED_AMOUNT = "FIXED_AMOUNT"
    MATCH = "MATCH"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, BenefitContributionTypeEnum._member_map_.values())
        )
