# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TimesheetToCreateContainerWithFile(BaseModel):
    """TimesheetToCreateContainerWithFile

    :param contract_id: Id of a Deel contract.
    :type contract_id: str
    :param description: description
    :type description: str
    :param date_submitted: Short date in format ISO-8601 (YYYY-MM-DD). For example: 2022-12-31.
    :type date_submitted: str
    :param quantity: This is based on the scale of work statement of the associated contract
    :type quantity: float
    :param file: Upload the file you want to attach to this entry., defaults to None
    :type file: str, optional
    """

    def __init__(
        self,
        contract_id: str,
        description: str,
        date_submitted: str,
        quantity: float,
        file: str = None,
    ):
        self.contract_id = contract_id
        self.description = description
        self.date_submitted = date_submitted
        self.quantity = quantity
        if file is not None:
            self.file = file
