# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class WebhookEventTypeResponse(BaseModel):
    """WebhookEventTypeResponse

    :param id_: Event type unique identifier.
    :type id_: float
    :param module_name: Name of the rabbit queue.
    :type module_name: str
    :param module_label: Display name of the rabbit queue in Deel UI.
    :type module_label: str
    :param name: Name of the webhook event.
    :type name: str
    :param description: Describes the webhook event and other pertinent info.
    :type description: str
    :param payload_example: JSON payload example of the specific event., defaults to None
    :type payload_example: str, optional
    :param created_at: Time at which the event type was created., defaults to None
    :type created_at: str, optional
    :param updated_at: Time at which the event type was updated., defaults to None
    :type updated_at: str, optional
    """

    def __init__(
        self,
        id_: float,
        module_name: str,
        module_label: str,
        name: str,
        description: str,
        payload_example: str = None,
        created_at: str = None,
        updated_at: str = None,
    ):
        self.id_ = id_
        self.module_name = module_name
        self.module_label = module_label
        self.name = name
        self.description = description
        if payload_example is not None:
            self.payload_example = payload_example
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
