# This file was generated by liblab | https://liblab.com/

from enum import Enum


class AdjustmentStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar OPEN: "open"
    :vartype OPEN: str
    :cvar PENDING_APPROVAL: "pending_approval"
    :vartype PENDING_APPROVAL: str
    :cvar OVERWRITTEN: "overwritten"
    :vartype OVERWRITTEN: str
    :cvar FAILED: "failed"
    :vartype FAILED: str
    :cvar SUCCESS: "success"
    :vartype SUCCESS: str
    """

    OPEN = "open"
    PENDING_APPROVAL = "pending_approval"
    OVERWRITTEN = "overwritten"
    FAILED = "failed"
    SUCCESS = "success"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, AdjustmentStatusEnum._member_map_.values()))
