# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class WorkerTermination(BaseModel):
    """WorkerTermination

    :param id_: id_
    :type id_: str
    :param last_date_of_work: Long date-time format following ISO-8601
    :type last_date_of_work: str
    """

    def __init__(self, id_: str, last_date_of_work: str):
        self.id_ = id_
        self.last_date_of_work = last_date_of_work
