# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee_timeoffs_item_response import EmployeeTimeoffsItemResponse


@JsonMap({})
class EmployeeTimeoffsCreationContainer(BaseModel):
    """EmployeeTimeoffsCreationContainer

    :param data: data
    :type data: EmployeeTimeoffsItemResponse
    """

    def __init__(self, data: EmployeeTimeoffsItemResponse):
        self.data = self._define_object(data, EmployeeTimeoffsItemResponse)
