# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .deel_invoice import DeelInvoice
from .page_info_without_cursor_new import PageInfoWithoutCursorNew


@JsonMap({})
class DeelInvoiceListContainer(BaseModel):
    """DeelInvoiceListContainer

    :param data: data
    :type data: List[DeelInvoice]
    :param page: page
    :type page: PageInfoWithoutCursorNew
    """

    def __init__(self, data: List[DeelInvoice], page: PageInfoWithoutCursorNew):
        self.data = self._define_list(data, DeelInvoice)
        self.page = self._define_object(page, PageInfoWithoutCursorNew)
