# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GenericResultCreatedData(BaseModel):
    """GenericResultCreatedData

    :param created: created
    :type created: bool
    """

    def __init__(self, created: bool):
        self.created = created


@JsonMap({})
class GenericResultCreated(BaseModel):
    """GenericResultCreated

    :param data: data
    :type data: GenericResultCreatedData
    """

    def __init__(self, data: GenericResultCreatedData):
        self.data = self._define_object(data, GenericResultCreatedData)
