# This file was generated by liblab | https://liblab.com/

from enum import Enum


class PaymentMethodEnum(Enum):
    """An enumeration representing different categories.

    :cvar STRIPE_BACS_DEBIT: "stripe_bacs_debit"
    :vartype STRIPE_BACS_DEBIT: str
    :cvar PAY_PAL: "pay_pal"
    :vartype PAY_PAL: str
    :cvar STRIPE_CARD: "stripe_card"
    :vartype STRIPE_CARD: str
    :cvar BT_CARD: "bt_card"
    :vartype BT_CARD: str
    :cvar STRIPE_ACH: "stripe_ach"
    :vartype STRIPE_ACH: str
    :cvar COINBASE: "coinbase"
    :vartype COINBASE: str
    :cvar GO_CARDLESS: "go_cardless"
    :vartype GO_CARDLESS: str
    :cvar BREX: "brex"
    :vartype BREX: str
    :cvar STRIPE_SEPA_DEBIT: "stripe_sepa_debit"
    :vartype STRIPE_SEPA_DEBIT: str
    :cvar TRANSFERWISE: "transferwise"
    :vartype TRANSFERWISE: str
    :cvar GO_CARDLESS_BECS: "go_cardless_becs"
    :vartype GO_CARDLESS_BECS: str
    :cvar BANK_TRANSFER: "bank_transfer"
    :vartype BANK_TRANSFER: str
    :cvar MERCURY_WIRE: "mercury_wire"
    :vartype MERCURY_WIRE: str
    :cvar BT_PAY_PAL: "bt_pay_pal"
    :vartype BT_PAY_PAL: str
    """

    STRIPE_BACS_DEBIT = "stripe_bacs_debit"
    PAY_PAL = "pay_pal"
    STRIPE_CARD = "stripe_card"
    BT_CARD = "bt_card"
    STRIPE_ACH = "stripe_ach"
    COINBASE = "coinbase"
    GO_CARDLESS = "go_cardless"
    BREX = "brex"
    STRIPE_SEPA_DEBIT = "stripe_sepa_debit"
    TRANSFERWISE = "transferwise"
    GO_CARDLESS_BECS = "go_cardless_becs"
    BANK_TRANSFER = "bank_transfer"
    MERCURY_WIRE = "mercury_wire"
    BT_PAY_PAL = "bt_pay_pal"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PaymentMethodEnum._member_map_.values()))
