# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .worker_termination_body import WorkerTerminationBody


@JsonMap({})
class WorkerTerminationBodyContainer(BaseModel):
    """WorkerTerminationBodyContainer

    :param data: data
    :type data: WorkerTerminationBody
    """

    def __init__(self, data: WorkerTerminationBody):
        self.data = self._define_object(data, WorkerTerminationBody)
