# This file was generated by liblab | https://liblab.com/

from enum import Enum


class TimeoffsStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar REQUESTED: "REQUESTED"
    :vartype REQUESTED: str
    :cvar APPROVED: "APPROVED"
    :vartype APPROVED: str
    :cvar REJECTED: "REJECTED"
    :vartype REJECTED: str
    """

    REQUESTED = "REQUESTED"
    APPROVED = "APPROVED"
    REJECTED = "REJECTED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TimeoffsStatusEnum._member_map_.values()))
