# This file was generated by liblab | https://liblab.com/

from enum import Enum


class ContractTypeEnumForEstimate(Enum):
    """An enumeration representing different categories.

    :cvar ONGOING_TIME_BASED: "ongoing_time_based"
    :vartype ONGOING_TIME_BASED: str
    :cvar PAYG_TASKS: "payg_tasks"
    :vartype PAYG_TASKS: str
    """

    ONGOING_TIME_BASED = "ongoing_time_based"
    PAYG_TASKS = "payg_tasks"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ContractTypeEnumForEstimate._member_map_.values())
        )
