# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_adjustment_to_update import InvoiceAdjustmentToUpdate


@JsonMap({})
class InvoiceAdjustmentToUpdateContainer(BaseModel):
    """InvoiceAdjustmentToUpdateContainer

    :param data: Details of invoice adjustment to update.
    :type data: InvoiceAdjustmentToUpdate
    """

    def __init__(self, data: InvoiceAdjustmentToUpdate):
        self.data = self._define_object(data, InvoiceAdjustmentToUpdate)
