# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class FileAttachmentInfo(BaseModel):
    """This object is used for linking file attachments to your records.

    :param filename: Original filename you used to upload using attachments end-point.
    :type filename: str
    :param key: You can call attachments end-point, get key and URL to upload your file.
    :type key: str
    """

    def __init__(self, filename: str, key: str):
        self.filename = filename
        self.key = key
