# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_details_to_amend import ContractDetailsToAmend


@JsonMap({})
class ContractToAmendDetailsContainer(BaseModel):
    """ContractToAmendDetailsContainer

    :param data: You can specify any combination of data points that need changing.
    :type data: ContractDetailsToAmend
    """

    def __init__(self, data: ContractDetailsToAmend):
        self.data = self._define_object(data, ContractDetailsToAmend)
