# This file was generated by liblab | https://liblab.com/

from typing import Union
from typing import List
from .base import OneOfBaseModel


class GetContractListCurrenciesGuard(OneOfBaseModel):
    class_list = {"List[str]": List[str], "str": str}


GetContractListCurrencies = Union[List[str], str]
