# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_adjustment_review_to_create import InvoiceAdjustmentReviewToCreate


@JsonMap({})
class InvoiceAdjustmentReviewToCreateContainer(BaseModel):
    """InvoiceAdjustmentReviewToCreateContainer

    :param data: data
    :type data: InvoiceAdjustmentReviewToCreate
    """

    def __init__(self, data: InvoiceAdjustmentReviewToCreate):
        self.data = self._define_object(data, InvoiceAdjustmentReviewToCreate)
