# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .identifier_value import IdentifierValue, IdentifierValueGuard


@JsonMap({"id_": "id"})
class ContractTemplateSummary(BaseModel):
    """ContractTemplateSummary

    :param id_: id_
    :type id_: IdentifierValue
    :param title: Title of a contract template
    :type title: str
    """

    def __init__(self, id_: IdentifierValue, title: str):
        self.id_ = IdentifierValueGuard.return_one_of(id_)
        self.title = title
