# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GpEmployeeAddressUpdateData(BaseModel):
    """GpEmployeeAddressUpdateData

    :param city: City name., defaults to None
    :type city: str, optional
    :param street: Street name., defaults to None
    :type street: str, optional
    :param zip: Zip code., defaults to None
    :type zip: str, optional
    """

    def __init__(self, city: str = None, street: str = None, zip: str = None):
        if city is not None:
            self.city = city
        if street is not None:
            self.street = street
        if zip is not None:
            self.zip = zip
