# This file was generated by liblab | https://liblab.com/

from enum import Enum


class ContractsSortByEnum(Enum):
    """An enumeration representing different categories.

    :cvar CONTRACT_TITLE: "contract_title"
    :vartype CONTRACT_TITLE: str
    :cvar WORKER_NAME: "worker_name"
    :vartype WORKER_NAME: str
    """

    CONTRACT_TITLE = "contract_title"
    WORKER_NAME = "worker_name"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ContractsSortByEnum._member_map_.values()))
