# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class GpPayrollEventReports(BaseModel):
    """GpPayrollEventReports

    :param id_: id_
    :type id_: str
    :param status: status
    :type status: str
    :param start_date: Long date-time format following ISO-8601
    :type start_date: str
    :param lock_date: Long date-time format following ISO-8601
    :type lock_date: str
    :param end_date: Long date-time format following ISO-8601
    :type end_date: str
    """

    def __init__(
        self, id_: str, status: str, start_date: str, lock_date: str, end_date: str
    ):
        self.id_ = id_
        self.status = status
        self.start_date = start_date
        self.lock_date = lock_date
        self.end_date = end_date
