# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class WorkerTerminationBody(BaseModel):
    """WorkerTerminationBody

    :param desired_end_date: The preferred end date for terminating the worker's engagement.
    :type desired_end_date: str
    :param last_date_of_work: The effective termination date of the worker's employment.
    :type last_date_of_work: str
    :param message: The reason for terminating the worker's engagement.
    :type message: str
    :param is_voluntary: Indicates whether the worker termination is voluntary (true) or involuntary (false).
    :type is_voluntary: bool
    :param severance: severance
    :type severance: dict
    """

    def __init__(
        self,
        desired_end_date: str,
        last_date_of_work: str,
        message: str,
        is_voluntary: bool,
        severance: dict,
    ):
        self.desired_end_date = desired_end_date
        self.last_date_of_work = last_date_of_work
        self.message = message
        self.is_voluntary = is_voluntary
        self.severance = severance
