# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class EquityStakeholder(BaseModel):
    """EquityStakeholder

    :param stakeholder_id: Unique identifier of the stakeholder., defaults to None
    :type stakeholder_id: str, optional
    :param worker_id: Unique identifier of the worker., defaults to None
    :type worker_id: str, optional
    """

    def __init__(self, stakeholder_id: str = None, worker_id: str = None):
        if stakeholder_id is not None:
            self.stakeholder_id = stakeholder_id
        if worker_id is not None:
            self.worker_id = worker_id
