# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class EorField(BaseModel):
    """Mandatory EOR field.

    :param label: label, defaults to None
    :type label: str, optional
    :param property_name: property_name, defaults to None
    :type property_name: str, optional
    :param input_type: input_type, defaults to None
    :type input_type: str, optional
    :param is_optional: is_optional, defaults to None
    :type is_optional: bool, optional
    :param options: options, defaults to None
    :type options: List[str], optional
    """

    def __init__(
        self,
        label: str = None,
        property_name: str = None,
        input_type: str = None,
        is_optional: bool = None,
        options: List[str] = None,
    ):
        if label is not None:
            self.label = label
        if property_name is not None:
            self.property_name = property_name
        if input_type is not None:
            self.input_type = input_type
        if is_optional is not None:
            self.is_optional = is_optional
        if options is not None:
            self.options = options
