# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class Team(BaseModel):
    """Team

    :param id_: Unique identifier of this resource., defaults to None
    :type id_: str, optional
    :param name: The name of the team., defaults to None
    :type name: str, optional
    """

    def __init__(self, id_: str = None, name: str = None):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = name
