# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .global_payroll_g2_n_report import GlobalPayrollG2NReport


@JsonMap({})
class GlobalPayrollG2NReportContainer(BaseModel):
    """GlobalPayrollG2NReportContainer

    :param data: data
    :type data: List[GlobalPayrollG2NReport]
    """

    def __init__(self, data: List[GlobalPayrollG2NReport]):
        self.data = self._define_list(data, GlobalPayrollG2NReport)
