# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class FirstPaymentDate(BaseModel):
    """First payment date

    :param due: Short date in format ISO-8601 (YYYY-MM-DD). For example: 2022-12-31., defaults to None
    :type due: str, optional
    """

    def __init__(self, due: str = None):
        if due is not None:
            self.due = due
