# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class BankAccountUpdated(BaseModel):
    """BankAccountUpdated

    :param id_: id_
    :type id_: str
    :param status: status
    :type status: str
    :param created_at: Long date-time format following ISO-8601
    :type created_at: str
    :param updated_at: Long date-time format following ISO-8601
    :type updated_at: str
    """

    def __init__(self, id_: str, status: str, created_at: str, updated_at: str):
        self.id_ = id_
        self.status = status
        self.created_at = created_at
        self.updated_at = updated_at
