# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class UpdateWorkerDepartment(BaseModel):
    """UpdateWorkerDepartment

    :param department_id: Unique identifier of this resource.
    :type department_id: str
    """

    def __init__(self, department_id: str):
        self.department_id = department_id
