# This file was generated by liblab | https://liblab.com/

from enum import Enum


class FileRefTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar APPLICATION_PDF: "application/pdf"
    :vartype APPLICATION_PDF: str
    :cvar TEXT_CSV: "text/csv"
    :vartype TEXT_CSV: str
    :cvar TEXT_PLAIN: "text/plain"
    :vartype TEXT_PLAIN: str
    :cvar IMAGE_JPEG: "image/jpeg"
    :vartype IMAGE_JPEG: str
    :cvar IMAGE_PNG: "image/png"
    :vartype IMAGE_PNG: str
    """

    APPLICATION_PDF = "application/pdf"
    TEXT_CSV = "text/csv"
    TEXT_PLAIN = "text/plain"
    IMAGE_JPEG = "image/jpeg"
    IMAGE_PNG = "image/png"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, FileRefTypeEnum._member_map_.values()))
