# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_to_create_pay_as_you_go_time_based import (
    ContractToCreatePayAsYouGoTimeBased,
)


@JsonMap({})
class ContractToCreateContainerPayAsYouGoTimeBased(BaseModel):
    """ContractToCreateContainerPayAsYouGoTimeBased

    :param data: data
    :type data: ContractToCreatePayAsYouGoTimeBased
    """

    def __init__(self, data: ContractToCreatePayAsYouGoTimeBased):
        self.data = self._define_object(data, ContractToCreatePayAsYouGoTimeBased)
