# This file was generated by liblab | https://liblab.com/

from enum import Enum


class PaymentStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar PAID: "paid"
    :vartype PAID: str
    :cvar PROCESSING: "processing"
    :vartype PROCESSING: str
    """

    PAID = "paid"
    PROCESSING = "processing"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PaymentStatusEnum._member_map_.values()))
