# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .invoice_adjustment_reviews_to_create import InvoiceAdjustmentReviewsToCreate


@JsonMap({})
class InvoiceAdjustmentReviewsToCreateContainer(BaseModel):
    """InvoiceAdjustmentReviewsToCreateContainer

    :param data: data
    :type data: InvoiceAdjustmentReviewsToCreate
    """

    def __init__(self, data: InvoiceAdjustmentReviewsToCreate):
        self.data = self._define_object(data, InvoiceAdjustmentReviewsToCreate)
