# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class OutputToCreateFileRef(BaseModel):
    """OutputToCreateFileRef

    :param key: key
    :type key: str
    :param url: url
    :type url: str
    """

    def __init__(self, key: str, url: str):
        self.key = key
        self.url = url
