# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class SignaturesOfBasicContract(BaseModel):
    """SignaturesOfBasicContract

    :param client_signed_at: Long date-time format following ISO-8601
    :type client_signed_at: str
    :param worker_signature: Worker's signature.
    :type worker_signature: str
    :param worker_signed_at: Long date-time format following ISO-8601
    :type worker_signed_at: str
    """

    def __init__(
        self, client_signed_at: str, worker_signature: str, worker_signed_at: str
    ):
        self.client_signed_at = client_signed_at
        self.worker_signature = worker_signature
        self.worker_signed_at = worker_signed_at
