# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class InvoiceAdjustmentToUpdate(BaseModel):
    """Details of invoice adjustment to update.

    :param description: description
    :type description: str
    :param amount: amount, defaults to None
    :type amount: float, optional
    """

    def __init__(self, description: str, amount: float = None):
        self.description = description
        if amount is not None:
            self.amount = amount
