# This file was generated by liblab | https://liblab.com/

from enum import Enum


class HiringStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar ACTIVE: "active"
    :vartype ACTIVE: str
    :cvar INACTIVE: "inactive"
    :vartype INACTIVE: str
    :cvar ONBOARDING: "onboarding"
    :vartype ONBOARDING: str
    """

    ACTIVE = "active"
    INACTIVE = "inactive"
    ONBOARDING = "onboarding"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, HiringStatusEnum._member_map_.values()))
