# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contract_termination_result import ContractTerminationResult


@JsonMap({})
class ContractTerminationResultContainer(BaseModel):
    """ContractTerminationResultContainer

    :param data: data
    :type data: ContractTerminationResult
    """

    def __init__(self, data: ContractTerminationResult):
        self.data = self._define_object(data, ContractTerminationResult)
