# This file was generated by liblab | https://liblab.com/

from enum import Enum


class WeekDaysEnum(Enum):
    """An enumeration representing different categories.

    :cvar SUNDAY: "Sunday"
    :vartype SUNDAY: str
    :cvar MONDAY: "Monday"
    :vartype MONDAY: str
    :cvar TUESDAY: "Tuesday"
    :vartype TUESDAY: str
    :cvar WEDNESDAY: "Wednesday"
    :vartype WEDNESDAY: str
    :cvar THURSDAY: "Thursday"
    :vartype THURSDAY: str
    :cvar FRIDAY: "Friday"
    :vartype FRIDAY: str
    :cvar SATURDAY: "Saturday"
    :vartype SATURDAY: str
    """

    SUNDAY = "Sunday"
    MONDAY = "Monday"
    TUESDAY = "Tuesday"
    WEDNESDAY = "Wednesday"
    THURSDAY = "Thursday"
    FRIDAY = "Friday"
    SATURDAY = "Saturday"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, WeekDaysEnum._member_map_.values()))
