# This file was generated by liblab | https://liblab.com/

from enum import Enum


class InvoiceAdjustmentTypeToCreateEnum(Enum):
    """An enumeration representing different categories.

    :cvar BONUS: "bonus"
    :vartype BONUS: str
    :cvar COMMISSION: "commission"
    :vartype COMMISSION: str
    :cvar DEDUCTION: "deduction"
    :vartype DEDUCTION: str
    :cvar EXPENSE: "expense"
    :vartype EXPENSE: str
    :cvar OTHER: "other"
    :vartype OTHER: str
    :cvar OVERTIME: "overtime"
    :vartype OVERTIME: str
    :cvar TIME_OFF: "time_off"
    :vartype TIME_OFF: str
    :cvar VAT: "vat"
    :vartype VAT: str
    """

    BONUS = "bonus"
    COMMISSION = "commission"
    DEDUCTION = "deduction"
    EXPENSE = "expense"
    OTHER = "other"
    OVERTIME = "overtime"
    TIME_OFF = "time_off"
    VAT = "vat"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                InvoiceAdjustmentTypeToCreateEnum._member_map_.values(),
            )
        )
