# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class AdjustmentCategory(BaseModel):
    """AdjustmentCategory

    :param id_: Unique identifier of an adjustment category., defaults to None
    :type id_: str, optional
    :param unit_type: The unit type of the adjustment category., defaults to None
    :type unit_type: str, optional
    :param label: The label of the adjustment category., defaults to None
    :type label: str, optional
    :param name: The name of the adjustment category., defaults to None
    :type name: str, optional
    """

    def __init__(
        self,
        id_: str = None,
        unit_type: str = None,
        label: str = None,
        name: str = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if unit_type is not None:
            self.unit_type = unit_type
        if label is not None:
            self.label = label
        if name is not None:
            self.name = name
