# This file was generated by liblab | https://liblab.com/

from enum import Enum


class WorkStatementCycleEndTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar DAY_OF_WEEK: "DAY_OF_WEEK"
    :vartype DAY_OF_WEEK: str
    :cvar DAY_OF_LAST_WEEK: "DAY_OF_LAST_WEEK"
    :vartype DAY_OF_LAST_WEEK: str
    :cvar DAY_OF_MONTH: "DAY_OF_MONTH"
    :vartype DAY_OF_MONTH: str
    """

    DAY_OF_WEEK = "DAY_OF_WEEK"
    DAY_OF_LAST_WEEK = "DAY_OF_LAST_WEEK"
    DAY_OF_MONTH = "DAY_OF_MONTH"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, WorkStatementCycleEndTypeEnum._member_map_.values())
        )
