# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .off_cycle_payment import OffCyclePayment


@JsonMap({})
class OffCyclePaymentContainer(BaseModel):
    """OffCyclePaymentContainer

    :param data: data
    :type data: OffCyclePayment
    """

    def __init__(self, data: OffCyclePayment):
        self.data = self._define_object(data, OffCyclePayment)
