# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PageInfoWithoutCursorNew(BaseModel):
    """PageInfoWithoutCursorNew

    :param total_rows: total_rows
    :type total_rows: float
    :param items_per_page: items_per_page
    :type items_per_page: float
    :param offset: offset
    :type offset: float
    """

    def __init__(self, total_rows: float, items_per_page: float, offset: float):
        self.total_rows = total_rows
        self.items_per_page = items_per_page
        self.offset = offset
