# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee_timeoffs_policies_item import EmployeeTimeoffsPoliciesItem


@JsonMap({})
class EmployeeTimeoffsPoliciesContainer(BaseModel):
    """EmployeeTimeoffsPoliciesContainer

    :param data: List of employee time offs policies.
    :type data: List[EmployeeTimeoffsPoliciesItem]
    """

    def __init__(self, data: List[EmployeeTimeoffsPoliciesItem]):
        self.data = self._define_list(data, EmployeeTimeoffsPoliciesItem)
