# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .job_title import JobTitle


@JsonMap({})
class Page(BaseModel):
    """Page

    :param cursor: Use for pagination to get next set of records after the given cursor.
    :type cursor: str
    """

    def __init__(self, cursor: str):
        self.cursor = cursor


@JsonMap({})
class JobTitleListContainer(BaseModel):
    """JobTitleListContainer

    :param data: data
    :type data: List[JobTitle]
    :param page: page
    :type page: Page
    """

    def __init__(self, data: List[JobTitle], page: Page):
        self.data = self._define_list(data, JobTitle)
        self.page = self._define_object(page, Page)
