# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GetEmployeeComplianceDocumentTemplateDownloadLinkContainerData(BaseModel):
    """GetEmployeeComplianceDocumentTemplateDownloadLinkContainerData

    :param url: The URL for the requested compliance document template., defaults to None
    :type url: str, optional
    :param expires_at: Expiration date time of download URL., defaults to None
    :type expires_at: str, optional
    """

    def __init__(self, url: str = None, expires_at: str = None):
        if url is not None:
            self.url = url
        if expires_at is not None:
            self.expires_at = expires_at


@JsonMap({})
class GetEmployeeComplianceDocumentTemplateDownloadLinkContainer(BaseModel):
    """GetEmployeeComplianceDocumentTemplateDownloadLinkContainer

    :param data: data
    :type data: GetEmployeeComplianceDocumentTemplateDownloadLinkContainerData
    """

    def __init__(
        self, data: GetEmployeeComplianceDocumentTemplateDownloadLinkContainerData
    ):
        self.data = self._define_object(
            data, GetEmployeeComplianceDocumentTemplateDownloadLinkContainerData
        )
