# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .timesheet_status_enum import TimesheetStatusEnum


@JsonMap({"id_": "id"})
class TaskCreated(BaseModel):
    """TaskCreated

    :param created: Whether the creation operation was successful., defaults to None
    :type created: bool, optional
    :param id_: Unique identifier of this resource., defaults to None
    :type id_: str, optional
    :param status: Status of this entry., defaults to None
    :type status: TimesheetStatusEnum, optional
    """

    def __init__(
        self, created: bool = None, id_: str = None, status: TimesheetStatusEnum = None
    ):
        if created is not None:
            self.created = created
        if id_ is not None:
            self.id_ = id_
        if status is not None:
            self.status = self._enum_matching(
                status, TimesheetStatusEnum.list(), "status"
            )
