# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"is_verified": "isVerified"})
class AlternateEmailItem(BaseModel):
    """AlternateEmailItem

    :param email: User's email address.
    :type email: str
    :param is_verified: is_verified
    :type is_verified: bool
    """

    def __init__(self, email: str, is_verified: bool):
        self.email = email
        self.is_verified = is_verified
