# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .team_of_basic_contract import TeamOfBasicContract


@JsonMap({})
class ClientOfBasicContract(BaseModel):
    """ClientOfBasicContract

    :param team: team, defaults to None
    :type team: TeamOfBasicContract, optional
    """

    def __init__(self, team: TeamOfBasicContract = None):
        if team is not None:
            self.team = self._define_object(team, TeamOfBasicContract)
