# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class BankAccountValueAllowed(BaseModel):
    """BankAccountValueAllowed

    :param value: The key of the allowed value., defaults to None
    :type value: str, optional
    :param label: The name of the allowed value., defaults to None
    :type label: str, optional
    """

    def __init__(self, value: str = None, label: str = None):
        if value is not None:
            self.value = value
        if label is not None:
            self.label = label
