# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GpContractStatusTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar FULL_TIME: "Full-time"
    :vartype FULL_TIME: str
    :cvar PART_TIME: "Part-time"
    :vartype PART_TIME: str
    """

    FULL_TIME = "Full-time"
    PART_TIME = "Part-time"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, GpContractStatusTypeEnum._member_map_.values())
        )
