# This file was generated by liblab | https://liblab.com/

from enum import Enum


class ProfileTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar CLIENT: "client"
    :vartype CLIENT: str
    :cvar CONTRACTOR: "contractor"
    :vartype CONTRACTOR: str
    :cvar ICP: "icp"
    :vartype ICP: str
    :cvar DIRECT_EMPLOYEE: "direct_employee"
    :vartype DIRECT_EMPLOYEE: str
    :cvar HRIS_DIRECT_EMPLOYEE: "hris_direct_employee"
    :vartype HRIS_DIRECT_EMPLOYEE: str
    :cvar SERVICE_ACCOUNT: "service_account"
    :vartype SERVICE_ACCOUNT: str
    """

    CLIENT = "client"
    CONTRACTOR = "contractor"
    ICP = "icp"
    DIRECT_EMPLOYEE = "direct_employee"
    HRIS_DIRECT_EMPLOYEE = "hris_direct_employee"
    SERVICE_ACCOUNT = "service_account"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ProfileTypeEnum._member_map_.values()))
