# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BenefitStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar REQUIRED: "REQUIRED"
    :vartype REQUIRED: str
    :cvar ENABLED: "ENABLED"
    :vartype ENABLED: str
    :cvar DISABLED: "DISABLED"
    :vartype DISABLED: str
    """

    REQUIRED = "REQUIRED"
    ENABLED = "ENABLED"
    DISABLED = "DISABLED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, BenefitStatusEnum._member_map_.values()))
