# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContractToTerminate(BaseModel):
    """ContractToTerminate

    :param completion_date: Short date in format ISO-8601 (YYYY-MM-DD). For example 2022-12-31., defaults to None
    :type completion_date: str, optional
    :param terminate_now: terminate_now, defaults to None
    :type terminate_now: bool, optional
    :param message: A message for the termination, defaults to None
    :type message: str, optional
    """

    def __init__(
        self,
        completion_date: str = None,
        terminate_now: bool = None,
        message: str = None,
    ):
        if completion_date is not None:
            self.completion_date = self._pattern_matching(
                completion_date, "^\d{4}-\d{2}-\d{2}$", "completion_date"
            )
        if terminate_now is not None:
            self.terminate_now = terminate_now
        if message is not None:
            self.message = message
