# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .basic_contract import BasicContract
from .page_info import PageInfo


@JsonMap({})
class ContractListContainer(BaseModel):
    """ContractListContainer

    :param data: data
    :type data: List[BasicContract]
    :param page: page
    :type page: PageInfo
    """

    def __init__(self, data: List[BasicContract], page: PageInfo):
        self.data = self._define_list(data, BasicContract)
        self.page = self._define_object(page, PageInfo)
