# This file was generated by liblab | https://liblab.com/

from enum import Enum


class TimesheetStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar APPROVED: "approved"
    :vartype APPROVED: str
    :cvar DECLINED: "declined"
    :vartype DECLINED: str
    :cvar NOT_PAYABLE: "not_payable"
    :vartype NOT_PAYABLE: str
    :cvar PAID: "paid"
    :vartype PAID: str
    :cvar PENDING: "pending"
    :vartype PENDING: str
    :cvar PROCESSING: "processing"
    :vartype PROCESSING: str
    """

    APPROVED = "approved"
    DECLINED = "declined"
    NOT_PAYABLE = "not_payable"
    PAID = "paid"
    PENDING = "pending"
    PROCESSING = "processing"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TimesheetStatusEnum._member_map_.values()))
