# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .eor_contract_created import EorContractCreated


@JsonMap({})
class EorContractCreatedContainer(BaseModel):
    """EorContractCreatedContainer

    :param data: data
    :type data: EorContractCreated
    """

    def __init__(self, data: EorContractCreated):
        self.data = self._define_object(data, EorContractCreated)
