# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .timesheet_to_update import TimesheetToUpdate


@JsonMap({})
class TimesheetToUpdateContainer(BaseModel):
    """TimesheetToUpdateContainer

    :param data: Details of the timesheet to update. Both a client or a contractor may update a timesheet.
    :type data: TimesheetToUpdate
    """

    def __init__(self, data: TimesheetToUpdate):
        self.data = self._define_object(data, TimesheetToUpdate)
