# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .file_attachment_info import FileAttachmentInfo


@JsonMap({})
class ContractDocumentContainer(BaseModel):
    """ContractDocumentContainer

    :param data: This object is used for linking file attachments to your records.
    :type data: FileAttachmentInfo
    """

    def __init__(self, data: FileAttachmentInfo):
        self.data = self._define_object(data, FileAttachmentInfo)
