# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TimeoffTypeListContainer(BaseModel):
    """TimeoffTypeListContainer

    :param data: data
    :type data: List[str]
    """

    def __init__(self, data: List[str]):
        self.data = data
