# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TimesheetApprover(BaseModel):
    """TimesheetApprover

    :param full_name: full_name
    :type full_name: str
    :param email: email
    :type email: str
    :param approved: approved
    :type approved: bool
    """

    def __init__(self, full_name: str, email: str, approved: bool):
        self.full_name = full_name
        self.email = email
        self.approved = approved
