# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .file_ref_type_enum import FileRefTypeEnum


@JsonMap({})
class InputToCreateFileRefData(BaseModel):
    """InputToCreateFileRefData

    :param content_type: type of files allowed when uploading attachments
    :type content_type: FileRefTypeEnum
    """

    def __init__(self, content_type: FileRefTypeEnum):
        self.content_type = self._enum_matching(
            content_type, FileRefTypeEnum.list(), "content_type"
        )


@JsonMap({})
class InputToCreateFileRef(BaseModel):
    """InputToCreateFileRef

    :param data: data
    :type data: InputToCreateFileRefData
    """

    def __init__(self, data: InputToCreateFileRefData):
        self.data = self._define_object(data, InputToCreateFileRefData)
