# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .worker_document import WorkerDocument


@JsonMap({})
class WorkerDocumentsByIdContainer(BaseModel):
    """WorkerDocumentsByIdContainer

    :param data: List of worker documents.
    :type data: List[WorkerDocument]
    """

    def __init__(self, data: List[WorkerDocument]):
        self.data = self._define_list(data, WorkerDocument)
