# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class GenericResultUpdatedData(BaseModel):
    """GenericResultUpdatedData

    :param updated: updated
    :type updated: bool
    """

    def __init__(self, updated: bool):
        self.updated = updated


@JsonMap({})
class GenericResultUpdated(BaseModel):
    """GenericResultUpdated

    :param data: data
    :type data: GenericResultUpdatedData
    """

    def __init__(self, data: GenericResultUpdatedData):
        self.data = self._define_object(data, GenericResultUpdatedData)
