# This file was generated by liblab | https://liblab.com/

from enum import Enum


class TimeoffsTypeEnum(Enum):
    """An enumeration representing different categories.

    :cvar VACATION: "VACATION"
    :vartype VACATION: str
    :cvar SICK_LEAVE: "SICK_LEAVE"
    :vartype SICK_LEAVE: str
    :cvar OTHER: "OTHER"
    :vartype OTHER: str
    """

    VACATION = "VACATION"
    SICK_LEAVE = "SICK_LEAVE"
    OTHER = "OTHER"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TimeoffsTypeEnum._member_map_.values()))
