# This file was generated by liblab | https://liblab.com/

from enum import Enum


class SalaryFrequencyScaleEnum(Enum):
    """An enumeration representing different categories.

    :cvar MONTHLY: "monthly"
    :vartype MONTHLY: str
    :cvar QUARTERLY: "quarterly"
    :vartype QUARTERLY: str
    :cvar ANNUALLY: "annually"
    :vartype ANNUALLY: str
    :cvar SPECIFIC_MONTH: "specific_month"
    :vartype SPECIFIC_MONTH: str
    :cvar SPECIFIC_DATE: "specific_date"
    :vartype SPECIFIC_DATE: str
    """

    MONTHLY = "monthly"
    QUARTERLY = "quarterly"
    ANNUALLY = "annually"
    SPECIFIC_MONTH = "specific_month"
    SPECIFIC_DATE = "specific_date"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SalaryFrequencyScaleEnum._member_map_.values())
        )
