# This file was generated by liblab | https://liblab.com/

from enum import Enum


class CandidateStatusEnum(Enum):
    """An enumeration representing different categories.

    :cvar OFFER_ACCEPTED: "offer-accepted"
    :vartype OFFER_ACCEPTED: str
    :cvar OFFER_SENT: "offer-sent"
    :vartype OFFER_SENT: str
    :cvar OFFER_DECLINED: "offer-declined"
    :vartype OFFER_DECLINED: str
    :cvar OFFER_DELETED: "offer-deleted"
    :vartype OFFER_DELETED: str
    """

    OFFER_ACCEPTED = "offer-accepted"
    OFFER_SENT = "offer-sent"
    OFFER_DECLINED = "offer-declined"
    OFFER_DELETED = "offer-deleted"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, CandidateStatusEnum._member_map_.values()))
