# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .estimate_first_payment import EstimateFirstPayment


@JsonMap({})
class EstimateFirstPaymentContainer(BaseModel):
    """EstimateFirstPaymentContainer

    :param data: Details of pro rata payment to create.
    :type data: EstimateFirstPayment
    """

    def __init__(self, data: EstimateFirstPayment):
        self.data = self._define_object(data, EstimateFirstPayment)
