# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .gp_employee_address_update_data import GpEmployeeAddressUpdateData


@JsonMap({})
class GpEmployeeAddressToUpdateContainer(BaseModel):
    """GpEmployeeAddressToUpdateContainer

    :param data: data
    :type data: GpEmployeeAddressUpdateData
    """

    def __init__(self, data: GpEmployeeAddressUpdateData):
        self.data = self._define_object(data, GpEmployeeAddressUpdateData)
