# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .adjustment_to_create import AdjustmentToCreate


@JsonMap({})
class AdjustmentToCreateContainer(BaseModel):
    """AdjustmentToCreateContainer

    :param data: Details of adjustment to create
    :type data: AdjustmentToCreate
    """

    def __init__(self, data: AdjustmentToCreate):
        self.data = self._define_object(data, AdjustmentToCreate)
