# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class EmployeeContractSignatureToCreate(BaseModel):
    """EmployeeContractSignatureToCreate

    :param signature: Signature of employee.
    :type signature: str
    """

    def __init__(self, signature: str):
        self.signature = signature
